@@ -7,8 +7,11 @@
 # Invenio-Drafts-Resources is free software; you can redistribute it and/or modify
 # it under the terms of the MIT License; see LICENSE file for more details.
 
-pydocstyle invenio_drafts_resources tests docs && \
-isort invenio_drafts_resources tests --check-only --diff && \
-# check-manifest --ignore ".travis-*" && \
-sphinx-build -qnNW docs docs/_build/html && \
-pytest
+docker-services-cli up postgresql es
+python -m check_manifest --ignore ".travis-*" && \
+python -m sphinx.cmd.build -qnNW docs docs/_build/html && \
+docker-services-cli up es postgresql redis
+python -m pytest
+tests_exit_code=$?
+docker-services-cli down
+exit "$tests_exit_code"
